@@ -5,7 +5,7 @@ use warnings;
 use vars qw[$VERSION %utilities];
 use Module::CoreList;
 
-$VERSION = '5.20170320';
+$VERSION = '5.20170420';
 
 sub utilities {
     my $perl = shift;
@@ -1249,6 +1249,13 @@ my %delta = (
         removed => {
         }
     },
+    5.025012 => {
+        delta_from => 5.025011,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
